@@ -33,23 +33,22 @@ class SherlockExplorer:
                        auto_detrend_ratio=1/4, detrend_method="cosine", smooth=False, sectors=None, cadence=300):
         lc_builder = LcBuilder()
         object_info = lc_builder.build_object_info(object_id, None, sectors, input_lc_file, cadence, None,
-                                                   None, None, None, None, None, False, smooth_enabled=smooth)
-        lc_build = \
-            lc_builder.build(object_info, ".")
-        lc = lc_build.lc.remove_outliers(sigma_lower=float('inf'), sigma_upper=3)  # remove outliers over 3sigma
+                                                   None, None, None, None,
+                                                   high_rms_enabled=False, smooth_enabled=smooth)
+        lc_build = lc_builder.build(object_info, ".")
+        lc = lc_build.lc
         flux = lc.flux.value
         flux_err = lc.flux_err.value
         if time_units == 0:
             time = lc.astropy_time.jd
         else:
             time = lc.time.value
-            #flux = uniform_filter1d(flux, 11)
         lc_df = pd.DataFrame(columns=['#time', 'flux', 'flux_err'])
         lc_df['#time'] = lc.time.value
-        lc_df['flux'] = flux
-        lc_df['flux_err'] = lc.flux_err.value.astype('<f4')
+        lc_df['flux'] = lc.flux.value
+        lc_df['flux_err'] = lc.flux_err.value
         lc_df = pd.DataFrame(columns=['flux'])
-        lc_df['flux'] = acf(flux, nlags=7200)
+        lc_df['flux'] = acf(lc.flux.value, nlags=7200)
         test_df = pd.DataFrame(lc_df)
         ax = test_df.plot()
         ax.set_ylim(lc_df["flux"].min(), lc_df["flux"].max())
@@ -58,29 +57,29 @@ class SherlockExplorer:
         #periodogram = lc.to_periodogram(oversample_factor=10)
         #fig = px.line(x=periodogram.period.astype('<f4'), y=periodogram.power.astype('<f4'), log_x=True)
         #fig.show()
-        fig = px.scatter(x=time, y=flux)
+        fig = px.scatter(x=lc.time.value, y=lc.flux.value)
         fig.show()
         if auto_detrend_periodic_signals:
             detrend_period = self.__calculate_max_significant_period(lc, periodogram)
             if detrend_period is not None:
                 flatten_lc, trend_lc = self.__detrend_by_period(lc, detrend_period * auto_detrend_ratio, detrend_method)
                 fig = go.Figure()
-                fig.add_trace(go.Scatter(x=lc.time.value.astype('<f4'), y=flux.astype('<f4'), mode='markers', name='Flux'))
-                fig.add_trace(go.Scatter(x=lc.time.value.astype('<f4'), y=trend_lc.astype('<f4'), mode='lines+markers',
+                fig.add_trace(go.Scatter(x=lc.time.value, y=flux, mode='markers', name='Flux'))
+                fig.add_trace(go.Scatter(x=lc.time.value, y=trend_lc, mode='lines+markers',
                                          name='Main Trend'))
                 fig.show()
                 if auto_detrend_periodic_signals:
-                    fig = px.line(x=lc.time.value.astype('<f4'), y=flatten_lc.astype('<f4'))
+                    fig = px.line(x=lc.time.value, y=flatten_lc)
                     fig.show()
                     lc.flux = flatten_lc
-        bin_means, bin_edges, binnumber = stats.binned_statistic(time, flux, statistic='mean',bins=len(time) / 5)
+        bin_means, bin_edges, binnumber = stats.binned_statistic(lc.time.value, lc.flux.value, statistic='mean',bins=len(time) / 5)
         bin_stds, _, _ = stats.binned_statistic(time, flux, statistic='std', bins=len(time) / 3)
         bin_width = (bin_edges[1] - bin_edges[0])
         bin_centers = bin_edges[1:] - bin_width / 2
         time_binned = bin_centers
         flux_binned = bin_means
         lc_binned = lk.LightCurve(time=time_binned, flux=flux_binned)
-        fig = px.scatter(x=lc_binned.time.value, y=lc_binned.flux.value)
+        fig = px.scatter(x=lc.time.value, y=lc.flux.value)
         fig.show()
         while True:
             try:
@@ -99,6 +98,14 @@ class SherlockExplorer:
             except ValueError:
                 print("Wrong number.")
                 continue
+            try:
+                user_input = input("Select the duration (minutes): ")
+                if user_input.startswith("q"):
+                    break
+                duration = float(user_input)
+            except ValueError:
+                print("Wrong number.")
+                continue
             # flux = lc.flux
             # args_flux_outer = np.argwhere(flux > 1 + depth * 0.001)
             # flux[args_flux_outer] = np.nan
@@ -109,13 +116,17 @@ class SherlockExplorer:
 
             j = 0
             fig_transit, axs = plt.subplots(4, 4, figsize=(16, 16))
+            duration_days = duration / 24 / 60
             #fig_transit.suptitle("Transit centered plots for TIC " + str(object_id))
-            for i in np.arange(t0, t0 + period * 16, period)[0:16]:
-                args_plot = np.argwhere((i - 0.1 < time) & (time < i + 0.1)).flatten()
-                plot_time = time[args_plot]
-                plot_flux = flux[args_plot]
-                axs[j // 4][j % 4].scatter(plot_time, plot_flux, color='gray', alpha=1, rasterized=True, label="Flux Transit " + str(j))
-                j = j + 1
+            for i in np.arange(t0, t0 + period * 100, period):
+                args_plot = np.argwhere((i - duration_days * 2 < time) & (time < i + duration_days * 2)).flatten()
+                if len(args_plot) > 10:
+                    plot_time = time[args_plot]
+                    plot_flux = flux[args_plot]
+                    axs[j // 4][j % 4].scatter(plot_time, plot_flux, color='gray', alpha=1, rasterized=True, label="Flux Transit " + str(j))
+                    j = j + 1
+                if j >= 16:
+                    break
             folded_lc = lk.LightCurve(time=lc.time, flux=lc.flux, flux_err=lc.flux_err)
             folded_lc.remove_nans()
             # folded_lc.flux_err = np.nan
@@ -124,7 +135,10 @@ class SherlockExplorer:
             plt.title("Phase-folded period: " + format(period, ".2f") + " days")
             plt.show()
             fig_transit.show()
-            fig = px.line(x=folded_lc.time.value.astype('<f4'), y=folded_lc.flux.value.astype('<f4'))
+            fig = px.line(x=folded_lc.time.value, y=folded_lc.flux.value)
+            fig.show()
+            mask = wotan.transit_mask(time, period, duration_days * 2, t0)
+            fig = px.scatter(x=time[mask], y=flux[mask])
             fig.show()
 
     def __parse_object_id(self, object_id):
