@@ -29,8 +29,7 @@ def elapsed_timer():
 
 with elapsed_timer() as elapsed:
     sherlock = sherlock_explorer.SherlockExplorer()
-    sherlock.explore_object("TIC 144065872", sectors="all", #input_lc_file="TOI-237.csv",
-                            auto_detrend_periodic_signals=False, smooth=True, cadence=120)
+    sherlock.explore_object("TIC 396720998", auto_detrend_periodic_signals=False, smooth=True, cadence=120)
 
     # sherlock = sherlock_class.Sherlock(n_detrends=3, auto_detrend_periodic_signals=True,
     #                                    mission_ids=["TIC 277539431"], mask_mode="subtract", id_lc={"TIC 277539431": 'sinteticos/modeled3.csv'})
