@@ -5,6 +5,10 @@ import re
 import shutil
 import sys
 from multiprocessing import Pool
+
+import foldedleastsquares
+import sklearn
+import wotan
 from sshkeyboard import listen_keyboard, stop_listening
 import keras
 import pandas as pd
@@ -181,50 +185,22 @@ class MlTrainingSetPreparer:
         return stars
 
     def store_lc_data(self, lc_data, file):
-        centroids_x = lc_data["centroids_x"][~np.isnan(lc_data["centroids_x"])].to_numpy()
-        centroids_y = lc_data["centroids_y"][~np.isnan(lc_data["centroids_y"])].to_numpy()
-        motion_x = lc_data["motion_x"][~np.isnan(lc_data["motion_x"])].to_numpy()
-        motion_y = lc_data["motion_y"][~np.isnan(lc_data["motion_y"])].to_numpy()
-        background_flux = lc_data["background_flux"][~np.isnan(lc_data["background_flux"])].to_numpy()
-        dif = centroids_x[1:] - centroids_x[:-1]
-        jumps = np.where(np.abs(dif) > 1)[0]
+        time = lc_data["time"].to_numpy()
+        dif = time[1:] - time[:-1]
+        jumps = np.where(np.abs(dif) > 0.5)[0]
         jumps = np.append(jumps, len(lc_data))
         previous_jump_index = 0
         for jumpIndex in jumps:
-            centroids_x_token = lc_data["centroids_x"][previous_jump_index:jumpIndex]
-            lc_data["centroids_x"][previous_jump_index:jumpIndex] = np.tanh(centroids_x_token - np.nanmedian(centroids_x_token))
-            previous_jump_index = jumpIndex
-        previous_jump_index = 0
-        dif = centroids_y[1:] - centroids_y[:-1]
-        jumps = np.where(np.abs(dif) > 1)[0]
-        jumps = np.append(jumps, len(lc_data))
-        for jumpIndex in jumps:
-            centroids_y_token = lc_data["centroids_y"][previous_jump_index:jumpIndex]
-            lc_data["centroids_y"][previous_jump_index:jumpIndex] = np.tanh(centroids_y_token - np.nanmedian(centroids_y_token))
-            previous_jump_index = jumpIndex
-        previous_jump_index = 0
-        dif = motion_x[1:] - motion_x[:-1]
-        jumps = np.where(np.abs(dif) > 1)[0]
-        jumps = np.append(jumps, len(lc_data))
-        for jumpIndex in jumps:
-            motion_x_token = lc_data["motion_x"][previous_jump_index:jumpIndex]
-            lc_data["motion_x"][previous_jump_index:jumpIndex] = np.tanh(motion_x_token - np.nanmedian(motion_x_token))
-            previous_jump_index = jumpIndex
-        previous_jump_index = 0
-        dif = motion_y[1:] - motion_y[:-1]
-        jumps = np.where(np.abs(dif) > 1)[0]
-        jumps = np.append(jumps, len(lc_data))
-        for jumpIndex in jumps:
-            motion_y_token = lc_data["motion_y"][previous_jump_index:jumpIndex]
-            lc_data["motion_y"][previous_jump_index:jumpIndex] = np.tanh(motion_y_token - np.nanmedian(motion_y_token))
-            previous_jump_index = jumpIndex
-        previous_jump_index = 0
-        dif = background_flux[1:] - background_flux[:-1]
-        jumps = np.where(np.abs(dif) > 1)[0]
-        jumps = np.append(jumps, len(lc_data))
-        for jumpIndex in jumps:
-            background_flux_token = lc_data["background_flux"][previous_jump_index:jumpIndex]
-            lc_data["background_flux"][previous_jump_index:jumpIndex] = np.tanh(background_flux_token - np.nanmedian(background_flux_token))
+            token = lc_data["centroids_x"][previous_jump_index:jumpIndex].to_numpy()
+            lc_data["centroids_x"][previous_jump_index:jumpIndex] = np.tanh(token - np.nanmedian(token))
+            token = lc_data["centroids_y"][previous_jump_index:jumpIndex].to_numpy()
+            lc_data["centroids_y"][previous_jump_index:jumpIndex] = np.tanh(token - np.nanmedian(token))
+            token = lc_data["motion_x"][previous_jump_index:jumpIndex].to_numpy()
+            lc_data["motion_x"][previous_jump_index:jumpIndex] = np.tanh(token - np.nanmedian(token))
+            token = lc_data["motion_y"][previous_jump_index:jumpIndex].to_numpy()
+            lc_data["motion_y"][previous_jump_index:jumpIndex] = np.tanh(token - np.nanmedian(token))
+            token = lc_data["background_flux"][previous_jump_index:jumpIndex].to_numpy()
+            lc_data["background_flux"][previous_jump_index:jumpIndex] = np.tanh(token - np.nanmedian(token))
             previous_jump_index = jumpIndex
         lc_data.to_csv(file)
         return lc_data
@@ -234,12 +210,6 @@ class MlTrainingSetPreparer:
         target_dir = prepare_tic_input.dir + tic_id + "/"
         if not os.path.isdir(target_dir):
             os.mkdir(target_dir)
-        tpfs_short_dir = target_dir + "tpfs_short/"
-        tpfs_long_dir = target_dir + "tpfs_long/"
-        if not os.path.isdir(tpfs_short_dir):
-            os.mkdir(tpfs_short_dir)
-        if not os.path.isdir(tpfs_long_dir):
-            os.mkdir(tpfs_long_dir)
         lc_short = None
         lc_data_short = None
         failed_target = None
@@ -252,13 +222,9 @@ class MlTrainingSetPreparer:
         try:
             logging.info("Trying to get short cadence info for " + str(prepare_tic_input.tic))
             lcbuild_short = \
-                mission_lightcurve_builder.build(MissionObjectInfo(tic_id, 'all'), None, self.cache_dir)
+                mission_lightcurve_builder.build(MissionObjectInfo(tic_id, 'all'), target_dir, self.cache_dir)
             lc_short = lcbuild_short.lc
             lc_data_short = self.store_lc_data(lcbuild_short.lc_data, target_dir + "time_series_short.csv")
-            tpf_short = lk.search_targetpixelfile(tic_id, cadence="short", author="spoc").download_all(
-                download_dir=self.cache_dir + ".lightkurve-cache")
-            for tpf in tpf_short.data:
-                shutil.copy(tpf.path, tpfs_short_dir + os.path.basename(tpf.path))
             short_periodogram = lc_short.to_periodogram(oversample_factor=5)
             periodogram_df = pd.DataFrame(columns=['period', 'power'])
             periodogram_df["period"] = short_periodogram.period.value
@@ -270,8 +236,7 @@ class MlTrainingSetPreparer:
         logging.info("Trying to get long cadence info for " + str(prepare_tic_input.tic))
         try:
             lcbuild_long = \
-                mission_ffi_lightcurve_builder.build(MissionFfiIdObjectInfo(tic_id, 'all'), None,
-                                                     self.cache_dir)
+                mission_ffi_lightcurve_builder.build(MissionFfiIdObjectInfo(tic_id, 'all'), target_dir, self.cache_dir)
             star_df = pd.DataFrame(columns=['obj_id', 'ra', 'dec', 'R_star', 'R_star_lerr', 'R_star_uerr', 'M_star',
                                                 'M_star_lerr', 'M_star_uerr', 'Teff_star', 'Teff_star_lerr',
                                                 'Teff_star_uerr', 'ld_a', 'ld_b'])
@@ -299,10 +264,6 @@ class MlTrainingSetPreparer:
             lc_long = lcbuild_long.lc
             lc_data_long = self.store_lc_data(lcbuild_long.lc_data, target_dir + "time_series_long.csv")
             lcf_long = lc_long.remove_nans()
-            tpf_long = lk.search_targetpixelfile(tic_id, cadence="long", author="tess-spoc")\
-                .download_all(download_dir=self.cache_dir + ".lightkurve-cache")
-            for tpf in tpf_long.data:
-                shutil.copy(tpf.path, tpfs_long_dir + os.path.basename(tpf.path))
             long_periodogram = lc_long.to_periodogram(oversample_factor=5)
             periodogram_df = pd.DataFrame(columns=['period', 'power'])
             periodogram_df["period"] = long_periodogram.period.value
@@ -311,12 +272,20 @@ class MlTrainingSetPreparer:
             logging.info("Downloading neighbour stars for " + prepare_tic_input.tic)
             #TODO get neighbours light curves stars = self.download_neighbours(prepare_tic_input.tic, sectors)
             logging.info("Classifying candidate points for " + prepare_tic_input.tic)
-            target_ois = prepare_tic_input.target_ois[
-                (prepare_tic_input.target_ois["Disposition"] == "CP") |
-                (prepare_tic_input.target_ois["Disposition"] == "KP")]
+            if prepare_tic_input.label == "TP":
+                target_ois = prepare_tic_input.target_ois[
+                    (prepare_tic_input.target_ois["Disposition"] == "CP") |
+                    (prepare_tic_input.target_ois["Disposition"] == "KP")]
+            elif prepare_tic_input.label == "FP":
+                target_ois = prepare_tic_input.target_ois[
+                    (prepare_tic_input.target_ois["Disposition"] == "FP") |
+                    (prepare_tic_input.target_ois["Disposition"] == "FA")]
+            else:
+                target_ois = prepare_tic_input.target_ois[
+                    (prepare_tic_input.target_ois["Disposition"] == "FAKE")]
             target_ois_df = pd.DataFrame(
                 columns=['id', 'name', 'period', 'period_err', 't0', 'to_err', 'depth', 'depth_err', 'duration',
-                         'duration_err'])
+                         'duration_err', 'score'])
             if lc_data_short is not None:
                 tags_series_short = np.full(len(lc_data_short.time), "BL")
             tags_series_long = np.full(len(lc_data_long.time), "BL")
@@ -330,7 +299,8 @@ class MlTrainingSetPreparer:
                              "period_err": row["Period (days) err"], "t0": row["Epoch (BJD)"] - 2457000.0,
                              "to_err": row["Epoch (BJD) err"], "depth": row["Depth (ppm)"],
                              "depth_err": row["Depth (ppm) err"], "duration": row["Duration (hours)"],
-                             "duration_err": row["Duration (hours) err"]}, ignore_index=True)
+                             "duration_err": row["Duration (hours) err"], "score": prepare_tic_input.score},
+                            ignore_index=True)
                         if lc_short is not None:
                             mask_short = tls.transit_mask(lc_data_short["time"].to_numpy(), row["Period (days)"],
                                                           row["Duration (hours)"] / 24, row["Epoch (BJD)"] - 2457000.0)
@@ -345,7 +315,8 @@ class MlTrainingSetPreparer:
                              "period_err": row["Period (days) err"], "t0": row["Epoch (BJD)"] - 2457000.0,
                              "to_err": row["Epoch (BJD) err"], "depth": row["Depth (ppm)"],
                              "depth_err": row["Depth (ppm) err"], "duration": row["Duration (hours)"],
-                             "duration_err": row["Duration (hours) err"]}, ignore_index=True)
+                             "duration_err": row["Duration (hours) err"], "score": prepare_tic_input.score},
+                            ignore_index=True)
                         if lc_short is not None:
                             mask_short = tls.transit_mask(lc_data_short["time"].to_numpy(), row["Period (days)"],
                                                           row["Duration (hours)"] / 24, row["Epoch (BJD)"] - 2457000.0)
@@ -517,37 +488,61 @@ class MlTrainingSetPreparer:
         positive_dir = root_dir + "/tp"
         false_positive_dir = root_dir + "/fp"
         negative_dir = root_dir + "/ntp"
-        sectors = np.arange(1, 27)
         logging.info("Flattening positive dir %s", positive_dir)
         for file in os.listdir(positive_dir):
             src = positive_dir + "/" + file
-            dst = flatten_dir + "/" + file
+            dst = flatten_dir + "/" + file + "_tp_"
             if os.path.exists(src + "/periodogram_" + mode + ".csv") and \
                     os.path.exists(src + "/time_series_" + mode + ".csv"):
-                os.symlink(src, dst)
-                with open(dst + "/score.txt", 'w') as the_file:
-                    the_file.write(str(1))
+                ois_df = pd.read_csv(src + "/ois.csv")
+                for index, oi_row in ois_df.iterrows():
+                    dst_index = dst + "_" + str(index)
+                    os.symlink(src, dst_index)
         logging.info("Flattening negative dir %s", negative_dir)
-        for file in os.listdir(negative_dir):
-            src = negative_dir + "/" + file
-            dst = flatten_dir + "/" + file
+        for file in os.listdir(false_positive_dir):
+            src = false_positive_dir + "/" + file
+            dst = flatten_dir + "/" + file + "_fp_"
             if os.path.exists(src + "/periodogram_" + mode + ".csv") and \
                     os.path.exists(src + "/time_series_" + mode + ".csv"):
-                os.symlink(src, dst, True)
-                with open(dst + "/score.txt", 'w') as the_file:
-                    the_file.write(str(0.5)) #TODO should be 0.5 or WHAT else?
+                ois_df = pd.read_csv(src + "/ois.csv")
+                for index, oi_row in ois_df.iterrows():
+                    dst_index = dst + "_" + str(index)
+                    os.symlink(src, dst_index)
         logging.info("Flattening false positive dir %s", false_positive_dir)
-        for file in os.listdir(false_positive_dir):
-            for sector in sectors:
-                tic_sector_file = file + "/" + str(sector) + "/"
-                for file_in_sector in os.listdir(tic_sector_file):
-                    src = tic_sector_file + "/" + file_in_sector
-                    dst = flatten_dir + "/" + file_in_sector
-                    if os.path.exists(src + "/periodogram_" + mode + ".csv") and \
-                            os.path.exists(src + "/time_series_" + mode + ".csv"):
-                        os.symlink(src, dst, True)
-                        with open(dst + "/score.txt", 'w') as the_file:
-                            the_file.write(str(0))
+        np.random.seed(0)
+        for file in os.listdir(negative_dir):
+            tic_sector_file = negative_dir + "/" + file
+            for file_in_sector in os.listdir(tic_sector_file):
+                src = tic_sector_file + "/" + file_in_sector
+                dst = flatten_dir + "/" + file_in_sector + "_ntp_0"
+                if os.path.exists(src + "/periodogram_" + mode + ".csv") and \
+                        os.path.exists(src + "/time_series_" + mode + ".csv"):
+                    os.symlink(src, dst)
+
+    @staticmethod
+    def split_training_test_and_validation_sets(cadence_dir):
+        labels = []
+        filenames = []
+        for file in os.listdir(cadence_dir):
+            filenames.append(file)
+            label = 0.0
+            if "_tp_" in file:
+                label = 1.0
+            elif "_fp_" in file:
+                label = 0.25 # TODO 0.25 or something else?
+            labels.append(label)
+        np.save(cadence_dir + '/filenames.npy', filenames)
+        labels = keras.utils.to_categorical(labels)
+        np.save(cadence_dir + '/labels.npy', labels)
+        filenames_shuffled, y_labels_one_hot_shuffled = sklearn.utils.shuffle(filenames, labels)
+        filenames_shuffled_numpy = np.array(filenames_shuffled)
+        x_train_filenames, x_val_filenames, y_train, y_val = sklearn.model_selection.train_test_split(
+            filenames_shuffled_numpy, labels, test_size=0.2, random_state=1)
+        np.save(cadence_dir + '/x_train_filenames.npy', x_train_filenames)
+        np.save(cadence_dir + '/y_train.npy', y_train)
+        np.save(cadence_dir + '/x_val_filenames.npy', x_val_filenames)
+        np.save(cadence_dir + '/y_val.npy', y_val)
+
 
 class PrepareTicInput:
     def __init__(self, dir, tic, target_ois, target_additional_ois_df, excluded_ois, label):
@@ -557,3 +552,8 @@ class PrepareTicInput:
         self.target_additional_ois_df = target_additional_ois_df
         self.excluded_ois = excluded_ois
         self.label = label
+        self.score = 0
+        if self.label == "TP":
+            self.score = 1.0
+        elif self.label == "FP":
+            self.score = 0.5
