@@ -7,7 +7,6 @@ from argparse import ArgumentParser
 import lcbuilder.eleanor
 sys.modules['eleanor'] = sys.modules['lcbuilder.eleanor']
 import eleanor
-from sherlockpipe.vet import Vetter
 from sherlockpipe.ois.OisManager import OisManager
 from eleanor.maxsector import maxsector
 
@@ -78,11 +77,6 @@ class Updater:
                         break
             with open(os.path.join(os.path.expanduser('~'), '.sherlockpipe/timestamp_eleanor.txt'), 'w+') as f:
                 f.write(str(time.time()))
-        if (force or time.time() - float(latte_timestamp) > 3600 * 24 * 7) and not ois:
-            print("------------------ Reloading LATTE data ------------------")
-            Vetter(None, False).update()
-            with open(os.path.join(os.path.expanduser('~'), '.sherlockpipe/timestamp_latte.txt'), 'w+') as f:
-                f.write(str(time.time()))
         print("DONE")
 
 
